@@ -129,6 +129,16 @@ try:
 except ImportError as error:
     get_bore_desc = error
 
+try:
+    from ..Methods.Machine.Lamination.comp_point_ref import comp_point_ref
+except ImportError as error:
+    comp_point_ref = error
+
+try:
+    from ..Methods.Machine.Lamination.get_label import get_label
+except ImportError as error:
+    get_label = error
+
 
 from ._check import InitUnKnowClassError
 from .Material import Material
@@ -383,6 +393,26 @@ class Lamination(FrozenClass):
         )
     else:
         get_bore_desc = get_bore_desc
+    # cf Methods.Machine.Lamination.comp_point_ref
+    if isinstance(comp_point_ref, ImportError):
+        comp_point_ref = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use Lamination method comp_point_ref: " + str(comp_point_ref)
+                )
+            )
+        )
+    else:
+        comp_point_ref = comp_point_ref
+    # cf Methods.Machine.Lamination.get_label
+    if isinstance(get_label, ImportError):
+        get_label = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use Lamination method get_label: " + str(get_label))
+            )
+        )
+    else:
+        get_label = get_label
     # save and copy methods are available in all object
     save = save
     copy = copy
@@ -739,7 +769,7 @@ class Lamination(FrozenClass):
 
     def _set_L1(self, value):
         """setter of L1"""
-        check_var("L1", value, "float", Vmin=0, Vmax=100)
+        check_var("L1", value, "float", Vmin=0)
         self._L1 = value
 
     L1 = property(
@@ -749,7 +779,6 @@ class Lamination(FrozenClass):
 
         :Type: float
         :min: 0
-        :max: 100
         """,
     )
 
