@@ -48,7 +48,7 @@ class OutStruct(FrozenClass):
         """Constructor of the class. Can be use in three ways :
         - __init__ (arg1 = 1, arg3 = 5) every parameters have name and default values
             for pyleecan type, -1 will call the default constructor
-        - __init__ (init_dict = d) d must be a dictionnary with property names as keys
+        - __init__ (init_dict = d) d must be a dictionary with property names as keys
         - __init__ (init_str = s) s must be a string
         s is the file path to load
 
@@ -151,9 +151,11 @@ class OutStruct(FrozenClass):
             return False
         return True
 
-    def compare(self, other, name="self"):
+    def compare(self, other, name="self", ignore_list=None):
         """Compare two objects and return list of differences"""
 
+        if ignore_list is None:
+            ignore_list = list()
         if type(other) != type(self):
             return ["type(" + name + ")"]
         diff_list = list()
@@ -205,6 +207,8 @@ class OutStruct(FrozenClass):
             )
         if other._FEA_dict != self._FEA_dict:
             diff_list.append(name + ".FEA_dict")
+        # Filter ignore differences
+        diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
 
     def __sizeof__(self):
@@ -515,7 +519,7 @@ class OutStruct(FrozenClass):
     FEA_dict = property(
         fget=_get_FEA_dict,
         fset=_set_FEA_dict,
-        doc=u"""Dictionnary containing the main FEA parameter
+        doc=u"""dictionary containing the main FEA parameter
 
         :Type: dict
         """,
