@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-from os.path import isdir, join
+from os.path import isdir, join, splitext
 from os import walk, getcwd, chdir
 from .Load.retrocompatibility import convert_init_dict
 from .Load.load_json import load_json
@@ -9,6 +9,10 @@ from .Load.load_pkl import load_pkl
 from .Load.import_class import import_class
 from ..Classes._check import InitUnKnowClassError
 
+# Matlib Keys
+LIB_KEY = "RefMatLib"
+MACH_KEY = "MachineMatLib"
+
 
 def init_data(obj, file_path):
     """
@@ -143,44 +147,102 @@ def load_dict(file_path):
     return _load(file_path, "dict")
 
 
-def load_matlib(mat_path):
+def load_matlib_folder(matlib_path):
     """Load all the Material json file from a folder and subfolder
 
     Parameters
     ----------
-    mat_path: str
+    matlib_path: str
         path to the file to load
 
     Returns
     -------
-    matlib: list
-        List of Material object
+    material_list: list
+        List of Material object from the Library
     """
 
     # Check that the dir exist
-    if not isdir(mat_path):
+    if not isdir(matlib_path):
         raise LoadMissingFolderError(
-            "The following given path doesn't lead to a directory: " + mat_path
+            "The following given path doesn't lead to a directory: " + matlib_path
         )
 
     # Get and Read all the file to create a list dictionary : variable name <=> value
-    matlib = list()
-    for (dirpath, _, filenames) in walk(mat_path):
+    material_list = list()
+    Material = import_class("pyleecan.Classes", "Material")
+    for (dirpath, _, filenames) in walk(matlib_path):
         for file_name in filenames:
             # For all json file in the folder and subfolder
             if file_name.endswith(".json") or file_name.endswith(".h5"):
-                file_path = join(dirpath, file_name)
+                file_path = join(dirpath, file_name).replace("\\", "/")
                 try:
                     mat = load(file_path)
                     # Update the object property
-                    mat.name = file_name[:-5]
+                    mat.name = splitext(file_name)[0]
                     mat.path = file_path
                     # Keep only the materials
-                    if isinstance(mat, import_class("pyleecan.Classes", "Material")):
-                        matlib.append(mat)
+                    if isinstance(mat, Material):
+                        material_list.append(mat)
                 except Exception:
                     print("When loading matlib, unable to load file: " + file_path)
-    return matlib
+    return material_list
+
+
+def load_machine_materials(material_dict, machine):
+    """Add the material from a machine that are different from the library one
+
+    Parameters
+    ----------
+    material_dict: dict
+        Materials dictionary (library + machine)
+    machine : Machine
+        Machine object to use the materials from
+    """
+    # Remove previous machine materials
+    material_dict[MACH_KEY] = list()
+    # Get machine materials (assume unique by name)
+    mach_mat_dict = machine.get_material_dict()
+    mach_mat_list = list(mach_mat_dict.values())
+
+    # Compare material with matlib (ignores name and path)
+    mat_lib_name = [mat.name for mat in material_dict[LIB_KEY]]
+    name_list = list()  # Machine materials name
+    for mach_mat in mach_mat_list:
+        if mach_mat.name in mat_lib_name:
+            # Machine material have a matching name in Library
+            lib_mat = material_dict[LIB_KEY][mat_lib_name.index(mach_mat.name)]
+            if mach_mat.compare(lib_mat, ignore_list=["self.name", "self.path"]):
+                # Machine material is different from library one : rename + add to list
+                mach_mat.name = mach_mat.name + "_old"
+                if mach_mat.name not in name_list:
+                    material_dict[MACH_KEY].append(mach_mat)
+                    name_list.append(mach_mat.name)
+        elif mach_mat.name not in name_list:  # Machine material not in Library
+            material_dict[MACH_KEY].append(mach_mat)
+            name_list.append(mach_mat.name)
+
+
+def load_matlib(matlib_path=None, machine=None):
+    """Load the Material library and the machine materials
+
+    Parameters
+    ----------
+    matlib_path: str
+        path to the Matlib folder to load
+    machine : Machine
+        Machine object to use the materials from
+
+    Returns
+    -------
+    material_dict: dict
+        Materials dictionary (library + machine)
+    """
+    material_dict = {LIB_KEY: list(), MACH_KEY: list(), "MATLIB_PATH": matlib_path}
+    if matlib_path is not None:
+        material_dict[LIB_KEY] = load_matlib_folder(matlib_path)
+    if machine is not None:
+        load_machine_materials(material_dict, machine)
+    return material_dict
 
 
 class LoadMissingFolderError(Exception):
