@@ -8,7 +8,6 @@ from PySide2.QtWidgets import QWidget
 from ......Classes.HoleM50 import HoleM50
 from ......GUI import gui_option
 from ......GUI.Dialog.DMachineSetup.SMHoleMag.PHoleM50.Gen_PHoleM50 import Gen_PHoleM50
-from ......GUI.Dialog.DMatLib.MatLib import MatLib
 from ......Methods.Slot.Slot import SlotCheckError
 
 
@@ -21,7 +20,7 @@ class PHoleM50(Gen_PHoleM50, QWidget):
     hole_name = "Hole Type 50"
     hole_type = HoleM50
 
-    def __init__(self, hole=None, matlib=MatLib()):
+    def __init__(self, hole=None, material_dict=None):
         """Initialize the widget according to hole
 
         Parameters
@@ -30,14 +29,14 @@ class PHoleM50(Gen_PHoleM50, QWidget):
             A PHoleM50 widget
         hole : HoleM50
             current hole to edit
-        matlib : MatLib
-            Material Library
+        material_dict: dict
+            Materials dictionary (library + machine)
         """
         # Build the interface according to the .ui file
         QWidget.__init__(self)
         self.setupUi(self)
 
-        self.matlib = matlib
+        self.material_dict = material_dict
         self.hole = hole
 
         # Set FloatEdit unit
@@ -68,14 +67,14 @@ class PHoleM50(Gen_PHoleM50, QWidget):
             self.img_slot.setPixmap(
                 QPixmap(":/images/images/MachineSetup/SMHoleMag/HoleM50_no_mag.png")
             )
-            self.w_mat_0.update(self.hole, "mat_void", self.matlib)
+            self.w_mat_0.update(self.hole, "mat_void", self.material_dict)
             self.w_mat_1.hide()
             self.w_mat_2.hide()
         else:
             # Set current material
-            self.w_mat_0.update(self.hole, "mat_void", self.matlib)
-            self.w_mat_1.update(self.hole.magnet_0, "mat_type", self.matlib)
-            self.w_mat_2.update(self.hole.magnet_1, "mat_type", self.matlib)
+            self.w_mat_0.update(self.hole, "mat_void", self.material_dict)
+            self.w_mat_1.update(self.hole.magnet_0, "mat_type", self.material_dict)
+            self.w_mat_2.update(self.hole.magnet_1, "mat_type", self.material_dict)
 
         # Set unit name (m ou mm)
         self.u = gui_option.unit
