@@ -106,7 +106,8 @@ class DMatSetup(Gen_DMatSetup, QDialog):
         self.lf_alpha_Br.setValue(self.mat.mag.alpha_Br)
         self.lf_Wlam.setValue(self.mat.mag.Wlam)
         # Setup import B(H) widget
-        self.w_BH_import.verbose_name = self.mat.name + " B(H) curve"
+        self.w_BH_import.verbose_name = "B(H) curve definition"
+        self.w_BH_import.plot_title = self.mat.name + " B(H) curve"
         self.w_BH_import.obj = self.mat.mag
         self.w_BH_import.param_name = "BH_curve"
         self.w_BH_import.expected_shape = (None, 2)
@@ -216,6 +217,7 @@ class DMatSetup(Gen_DMatSetup, QDialog):
         self.mat.path = rel_file_path(
             join(dirname(self.mat.path), file_name + ".json"), "MATLIB_DIR"
         )
+        self.w_BH_import.set_plot_title(self.mat.name + " B(H) curve")
         self.is_save_needed = True
 
     def set_is_isotropic(self, is_checked):
