@@ -1,8 +1,8 @@
 from .....GUI.Dialog.DMatLib.WMatSelect.Ui_WMatSelect import Ui_WMatSelect
-from .....GUI.Dialog.DMatLib.DMatLib import DMatLib
-from PySide2.QtWidgets import QWidget, QMessageBox, QDialog
-from .....Classes.Material import Material
+from .....GUI.Dialog.DMatLib.DMatLib import DMatLib, LIB_KEY, MACH_KEY
+from PySide2.QtWidgets import QWidget
 from PySide2.QtCore import Signal
+from .....Classes.Machine import Machine
 
 
 class WMatSelect(Ui_WMatSelect, QWidget):
@@ -38,12 +38,11 @@ class WMatSelect(Ui_WMatSelect, QWidget):
         QWidget.__init__(self, parent)
         self.setupUi(self)
 
+        self.current_dialog = None
         # Create the property of the widget
-        self.current_dialog = None  # DMatLib widget
         self.obj = None  # object that has a material attribute
         self.mat_attr_name = ""  # material attribute name
-        self.matlib = list()  # Matlib
-        self.matlib_path = ""  # Path to save the matlib
+        self.material_dict = dict()  #  Material library + machine
         self.def_mat = "M400-50A"  # Default material
         self.is_hide_button = False  # To hide the "Edit material" button
 
@@ -51,7 +50,7 @@ class WMatSelect(Ui_WMatSelect, QWidget):
         self.c_mat_type.currentIndexChanged.connect(self.set_mat_type)
         self.b_matlib.clicked.connect(self.s_open_matlib)
 
-    def update(self, obj, mat_attr_name, matlib, matlib_path=""):
+    def update(self, obj, mat_attr_name, material_dict):
         """
         Set a reference to a material libray and material data path,
         updates the Combobox by the material names of the libary
@@ -59,16 +58,14 @@ class WMatSelect(Ui_WMatSelect, QWidget):
 
         Parameters
         ----------
-        self :
+        self : WMatSelect
             A WMatSelect object
-        obj :
+        obj : FrozenObject
             A pyleecan object that has a material attribute
-        mat_attr_name :
+        mat_attr_name : str
             A string of the material attribute name
-        matlib :
-            A material libary, i.e. a list of Material objects
-        matlib_path :
-            A string containing the path of material data
+        material_dict: dict
+            Materials dictionary (library + machine)
 
         Returns
         -------
@@ -79,8 +76,13 @@ class WMatSelect(Ui_WMatSelect, QWidget):
         # Set material combobox according to matlib names
         self.obj = obj
         self.mat_attr_name = mat_attr_name
-        self.matlib = matlib
-        self.matlib_path = matlib_path
+        self.material_dict = material_dict
+
+        # Get machine object to update the materials
+        parent = obj.parent
+        while parent is not None and not isinstance(parent, Machine):
+            parent = parent.parent
+        self.machine = parent
 
         if self.is_hide_button:
             self.b_matlib.hide()
@@ -90,22 +92,21 @@ class WMatSelect(Ui_WMatSelect, QWidget):
         # Update the list of materials
         self.c_mat_type.clear()
         items_to_add = []
-        # Add RefMatLib materials
-        items_to_add.extend([mat.name for mat in matlib.dict_mat["RefMatLib"]])
+        # Add Library materials
+        items_to_add.extend([mat.name for mat in material_dict[LIB_KEY]])
         # Add machine-specific materials
-        items_to_add.extend([mat.name for mat in matlib.dict_mat["MachineMatLib"]])
+        items_to_add.extend([mat.name for mat in material_dict[MACH_KEY]])
         self.c_mat_type.addItems(items_to_add)
 
         mat = getattr(self.obj, mat_attr_name, None)
         if mat is None or mat.name is None:
-            # Default lamination material: M400-50A
+            # Select default material
             index = self.c_mat_type.findText(self.def_mat)
             if index != -1:
-                # self.mat.__init__(init_dict=self.matlib[index].as_dict())
                 setattr(
                     self.obj,
                     self.mat_attr_name,
-                    self.matlib.dict_mat["RefMatLib"][index],
+                    self.material_dict[LIB_KEY][index],
                 )
         else:
             index = self.c_mat_type.findText(mat.name)
@@ -145,13 +146,13 @@ class WMatSelect(Ui_WMatSelect, QWidget):
         -------
 
         """
-        if index >= len(self.matlib.dict_mat["RefMatLib"]):
-            index -= len(self.matlib.dict_mat["RefMatLib"])
-            dict_key = "MachineMatLib"
+        if index >= len(self.material_dict[LIB_KEY]):
+            index -= len(self.material_dict[LIB_KEY])
+            dict_key = MACH_KEY
         else:
-            dict_key = "RefMatLib"
+            dict_key = LIB_KEY
 
-        setattr(self.obj, self.mat_attr_name, self.matlib.dict_mat[dict_key][index])
+        setattr(self.obj, self.mat_attr_name, self.material_dict[dict_key][index])
         # Notify the machine GUI that the machine has changed
         self.saveNeeded.emit()
 
@@ -168,16 +169,19 @@ class WMatSelect(Ui_WMatSelect, QWidget):
         -------
 
         """
-        if self.c_mat_type.currentIndex() >= len(self.matlib.dict_mat["RefMatLib"]):
-            index = self.c_mat_type.currentIndex() - len(
-                self.matlib.dict_mat["RefMatLib"]
-            )
-            key = "MachineMatLib"
+        if self.c_mat_type.currentIndex() >= len(self.material_dict[LIB_KEY]):
+            index = self.c_mat_type.currentIndex() - len(self.material_dict[LIB_KEY])
+            is_lib_mat = False
         else:
             index = self.c_mat_type.currentIndex()
-            key = "RefMatLib"
-        self.current_dialog = DMatLib(self.matlib, key, index)
-        self.current_dialog.accepted.connect(self.set_matlib)
+            is_lib_mat = True
+        self.current_dialog = DMatLib(
+            material_dict=self.material_dict,
+            machine=self.machine,
+            is_lib_mat=is_lib_mat,
+            selected_id=index,
+        )
+        self.current_dialog.materialListChanged.connect(self.update_mat_list)
         self.current_dialog.saveNeeded.connect(self.emit_save)
         self.current_dialog.show()
 
@@ -187,8 +191,8 @@ class WMatSelect(Ui_WMatSelect, QWidget):
         """
         self.saveNeeded.emit()
 
-    def set_matlib(self):
-        """Update the matlib with the new value
+    def update_mat_list(self):
+        """Update the combobox with the new materials
 
         Parameters
         ----------
@@ -222,9 +226,9 @@ class WMatSelect(Ui_WMatSelect, QWidget):
 
         items_to_add = []
         # Add RefMatLib materials
-        items_to_add.extend([mat.name for mat in self.matlib.dict_mat["RefMatLib"]])
+        items_to_add.extend([mat.name for mat in self.material_dict[LIB_KEY]])
         # Add machine-specific materials
-        items_to_add.extend([mat.name for mat in self.matlib.dict_mat["MachineMatLib"]])
+        items_to_add.extend([mat.name for mat in self.material_dict[MACH_KEY]])
         self.c_mat_type.addItems(items_to_add)
 
         index = self.c_mat_type.findText(getattr(self.obj, self.mat_attr_name).name)
