@@ -26,6 +26,7 @@ from ...GUI.Tools.FloatEdit import FloatEdit
 from ...GUI import gui_option
 from ...loggers import GUI_LOG_NAME
 from .Ui_DXF_Hole import Ui_DXF_Hole
+from ...Functions.labels import HOLEM_LAB, HOLEV_LAB
 
 # Column index for table
 
@@ -80,9 +81,6 @@ class DXF_Hole(Ui_DXF_Hole, QDialog):
         self.init_graph()
 
         # Not used yet
-        self.in_coord_center.hide()
-        self.lf_center_x.hide()
-        self.lf_center_y.hide()
         self.lf_axe_angle.hide()
         self.in_axe_angle.hide()
         self.unit_axe_angle.hide()
@@ -101,6 +99,9 @@ class DXF_Hole(Ui_DXF_Hole, QDialog):
         self.line_list = list()  # List of line from DXF
         self.selected_list = list()  # List of currently selected lines
         self.surf_list = list()  # List of defined surfaces
+        self.Zcenter = 0  # For translate offset
+
+        # Set DXF edit widget
         self.lf_center_x.setValue(0)
         self.lf_center_y.setValue(0)
         self.lf_scaling.validator().setBottom(0)
@@ -134,6 +135,8 @@ class DXF_Hole(Ui_DXF_Hole, QDialog):
         self.b_reset.pressed.connect(self.update_graph)
         self.b_cancel.pressed.connect(self.remove_selection)
         self.b_tuto.pressed.connect(self.open_tuto)
+        self.lf_center_x.editingFinished.connect(self.set_center)
+        self.lf_center_y.editingFinished.connect(self.set_center)
 
         # Display the GUI
         self.show()
@@ -254,6 +257,11 @@ class DXF_Hole(Ui_DXF_Hole, QDialog):
         axes.axis("equal")
         axes.set_axis_off()
 
+    def set_center(self):
+        """Update the position of the center"""
+        self.Zcenter = self.lf_center_x.value() + 1j * self.lf_center_y.value()
+        self.update_graph()
+
     def update_graph(self):
         """Clean and redraw all the lines in viewer
 
@@ -271,6 +279,9 @@ class DXF_Hole(Ui_DXF_Hole, QDialog):
             point_list = array(line.discretize(20))
             color = COLOR_LIST[self.selected_list[ii]]
             axes.plot(point_list.real, point_list.imag, color, zorder=1)
+        # Add lamination center
+        axes.plot(self.Zcenter.real, self.Zcenter.imag, "rx", zorder=0)
+        axes.text(self.Zcenter.real, self.Zcenter.imag, "O")
 
         self.w_viewer.draw()
 
@@ -447,9 +458,9 @@ class DXF_Hole(Ui_DXF_Hole, QDialog):
             hole.surf_list.append(self.surf_list[ii].copy())
             hole.surf_list[ii].scale(self.lf_scaling.value())
             if self.w_surface_list.cellWidget(ii, TYPE_COL).currentIndex() == 0:
-                hole.surf_list[ii].label = "Hole"
+                hole.surf_list[ii].label = HOLEV_LAB
             else:
-                hole.surf_list[ii].label = "HoleMagnet"
+                hole.surf_list[ii].label = HOLEM_LAB
                 Nmag += 1
             bottom_list.append(
                 self.line_list[
@@ -470,6 +481,11 @@ class DXF_Hole(Ui_DXF_Hole, QDialog):
         offset_list_sorted = [offset_list[ii] for ii in idx]
         hole.surf_list = surf_list_sorted
 
+        # Translate
+        if self.Zcenter != 0:
+            for surf in hole.surf_list:
+                surf.translate(-self.Zcenter * self.lf_scaling.value())
+
         # Rotation
         Zref = sum([surf.point_ref for surf in hole.surf_list])
         for surf in hole.surf_list:
@@ -479,7 +495,7 @@ class DXF_Hole(Ui_DXF_Hole, QDialog):
         mag_dict = dict()
         Nmag = 0
         for ii in range(len(hole.surf_list)):
-            if "Magnet" in hole.surf_list[ii].label:
+            if HOLEM_LAB in hole.surf_list[ii].label:
                 line = bottom_list_sorted[ii].copy()
                 line.rotate(-1 * np_angle(Zref))
                 mag_dict["magnet_" + str(Nmag)] = line.comp_normal()
@@ -502,7 +518,7 @@ class DXF_Hole(Ui_DXF_Hole, QDialog):
         mag_list = list()
         hole_list = list()
         for surf in hole.surf_list:
-            if "HoleMagnet" in surf.label:
+            if HOLEM_LAB in surf.label:
                 mag_list.append(surf)
             else:
                 hole_list.append(surf)
@@ -510,7 +526,7 @@ class DXF_Hole(Ui_DXF_Hole, QDialog):
 
         # Correct hole ref_point (when Magnets are inside Hole surface)
         for surf in hole.surf_list:
-            if "HoleMagnet" not in surf.label:
+            if HOLEV_LAB in surf.label:
                 line_list = surf.get_lines()
                 # Get middle list
                 middle_array = array([line.get_middle() for line in line_list])
@@ -614,8 +630,15 @@ class DXF_Hole(Ui_DXF_Hole, QDialog):
         )[0]
         if save_file_path not in ["", ".json", None]:
             self.save_path = save_file_path
-            hole.save(save_file_path)
-            self.accept()
+            try:
+                hole.save(save_file_path)
+                self.accept()
+            except Exception as e:
+                QMessageBox().critical(
+                    self,
+                    self.tr("Error"),
+                    self.tr("Error while saving hole json file:\n" + str(e)),
+                )
 
     def open_tuto(self):
         """Open the tutorial video in a web browser"""
