@@ -9,9 +9,9 @@ from PySide2.QtCore import *
 from PySide2.QtGui import *
 from PySide2.QtWidgets import *
 
-from ...GUI.Tools.WPathSelector.WPathSelector import WPathSelector
 from ...GUI.Tools.MPLCanvas import MPLCanvas2
 from ...GUI.Tools.FloatEdit import FloatEdit
+from ...GUI.Tools.WPathSelector.WPathSelector import WPathSelector
 
 from pyleecan.GUI.Resources import pyleecan_rc
 
@@ -20,7 +20,7 @@ class Ui_DXF_Hole(object):
     def setupUi(self, DXF_Hole):
         if not DXF_Hole.objectName():
             DXF_Hole.setObjectName(u"DXF_Hole")
-        DXF_Hole.resize(783, 484)
+        DXF_Hole.resize(783, 653)
         icon = QIcon()
         icon.addFile(
             u":/images/images/icon/pyleecan_64.png", QSize(), QIcon.Normal, QIcon.Off
@@ -156,31 +156,37 @@ class Ui_DXF_Hole(object):
 
         self.verticalLayout.addLayout(self.gridLayout)
 
-        self.horizontalLayout_5 = QHBoxLayout()
-        self.horizontalLayout_5.setObjectName(u"horizontalLayout_5")
-        self.horizontalLayout_5.setSizeConstraint(QLayout.SetMinimumSize)
-        self.in_coord_center = QLabel(self.w_side)
-        self.in_coord_center.setObjectName(u"in_coord_center")
+        self.g_center = QGroupBox(self.w_side)
+        self.g_center.setObjectName(u"g_center")
+        self.gridLayout_3 = QGridLayout(self.g_center)
+        self.gridLayout_3.setObjectName(u"gridLayout_3")
+        self.in_coord_center_X = QLabel(self.g_center)
+        self.in_coord_center_X.setObjectName(u"in_coord_center_X")
 
-        self.horizontalLayout_5.addWidget(self.in_coord_center)
+        self.gridLayout_3.addWidget(self.in_coord_center_X, 0, 0, 1, 1)
 
-        self.lf_center_x = FloatEdit(self.w_side)
+        self.lf_center_x = FloatEdit(self.g_center)
         self.lf_center_x.setObjectName(u"lf_center_x")
         sizePolicy2.setHeightForWidth(self.lf_center_x.sizePolicy().hasHeightForWidth())
         self.lf_center_x.setSizePolicy(sizePolicy2)
 
-        self.horizontalLayout_5.addWidget(self.lf_center_x)
+        self.gridLayout_3.addWidget(self.lf_center_x, 0, 1, 1, 1)
 
-        self.lf_center_y = FloatEdit(self.w_side)
+        self.in_coord_center_Y = QLabel(self.g_center)
+        self.in_coord_center_Y.setObjectName(u"in_coord_center_Y")
+
+        self.gridLayout_3.addWidget(self.in_coord_center_Y, 1, 0, 1, 1)
+
+        self.lf_center_y = FloatEdit(self.g_center)
         self.lf_center_y.setObjectName(u"lf_center_y")
         self.lf_center_y.setEnabled(True)
         sizePolicy2.setHeightForWidth(self.lf_center_y.sizePolicy().hasHeightForWidth())
         self.lf_center_y.setSizePolicy(sizePolicy2)
-        self.lf_center_y.setMaximumSize(QSize(137, 16777215))
+        self.lf_center_y.setMaximumSize(QSize(16777215, 16777215))
 
-        self.horizontalLayout_5.addWidget(self.lf_center_y)
+        self.gridLayout_3.addWidget(self.lf_center_y, 1, 1, 1, 1)
 
-        self.verticalLayout.addLayout(self.horizontalLayout_5)
+        self.verticalLayout.addWidget(self.g_center)
 
         self.w_surface_list = QTableWidget(self.w_side)
         if self.w_surface_list.columnCount() < 5:
@@ -305,10 +311,16 @@ class Ui_DXF_Hole(object):
         self.unit_axe_angle.setText(
             QCoreApplication.translate("DXF_Hole", u"[rad]", None)
         )
-        self.in_coord_center.setText(
-            QCoreApplication.translate("DXF_Hole", u"Machine center (x,y)", None)
+        self.g_center.setTitle(
+            QCoreApplication.translate("DXF_Hole", u"Machine Center", None)
+        )
+        self.in_coord_center_X.setText(
+            QCoreApplication.translate("DXF_Hole", u"X coordinate", None)
         )
         self.lf_center_x.setText(QCoreApplication.translate("DXF_Hole", u"0", None))
+        self.in_coord_center_Y.setText(
+            QCoreApplication.translate("DXF_Hole", u"Y coordinate", None)
+        )
         self.lf_center_y.setText(QCoreApplication.translate("DXF_Hole", u"0", None))
         ___qtablewidgetitem = self.w_surface_list.horizontalHeaderItem(0)
         ___qtablewidgetitem.setText(
