@@ -1,6 +1,5 @@
 def comp_step(self):
-    """Compute the Step between two points of the linspace
-    """
+    """Compute the Step between two points of the linspace"""
 
     self.check()
     data = self.get_data()
