@@ -2,7 +2,6 @@ from ....Methods.Import import ImportError
 
 
 class MatFileError(ImportError):
-    """Raised when the file_path is wrong or the variable is missing
-    """
+    """Raised when the file_path is wrong or the variable is missing"""
 
     pass
