@@ -1,7 +1,7 @@
 from ....Functions.Geometry.merge_notch_list import merge_notch_list
 
 
-def get_notch_list(self, sym=1):
+def get_notch_list(self, sym=1, is_yoke=False):
     """Returns an ordered description of the notches
 
     Parameters
@@ -10,6 +10,8 @@ def get_notch_list(self, sym=1):
         A Lamination object
     sym: int
         Number of symmetry
+    is_yoke : bool
+        Selected yoke or bore notches
 
     Returns
     -------
@@ -17,14 +19,19 @@ def get_notch_list(self, sym=1):
         list of dictionary with key: "begin_angle", "end_angle", "obj"
     """
 
-    if self.notch is None or len(self.notch) == 0:  # No notch
+    if is_yoke:
+        notch_list = self.yoke_notch
+    else:
+        notch_list = self.notch
+
+    if notch_list is None or len(notch_list) == 0:  # No notch
         return list()
     else:
-        notch_list = self.notch[0].get_notch_list(sym=sym)
+        desc_list = notch_list[0].get_notch_list(sym=sym, is_yoke=is_yoke)
         # If more than one notch list, we need to merge in order the description
         # (check if notches are coliding)
-        for ii in range(len(self.notch) - 1):
-            notch_list = merge_notch_list(
-                notch_list, self.notch[ii + 1].get_notch_list(sym=sym)
+        for ii in range(len(notch_list) - 1):
+            desc_list = merge_notch_list(
+                desc_list, notch_list[ii + 1].get_notch_list(sym=sym, is_yoke=is_yoke)
             )
-        return notch_list
+        return desc_list
