@@ -23,11 +23,11 @@ def is_exist(self, connectivity):
     # Check the existence of the element
     e = np.array([], dtype=int)
     for nd_tag in connectivity:
-        e = np.concatenate((e, self.get_point2cell(nd_tag)))
+        e = np.concatenate((e, self.get_node2cell(nd_tag)))
 
     unique, unique_counts = np.unique(e, return_counts=True)
     for ie in range(len(unique)):
-        if unique_counts[ie] == self.nb_pt_per_cell and unique_counts[ie] == len(
+        if unique_counts[ie] == self.nb_node_per_cell and unique_counts[ie] == len(
             connectivity
         ):
             # If this condition is valid, the element already exist
