@@ -153,7 +153,8 @@ def gen_input(self):
 
     if self.Tem_av_ref is not None:
         output.Tem_av_ref = self.Tem_av_ref
-
+    if self.Pem_av_ref is not None:
+        output.Pem_av_ref = self.Pem_av_ref
     if simu.parent is None:
         raise InputError(
             "ERROR: The Simulation object must be in an Output object to run"
