@@ -2,8 +2,7 @@ from numpy import cos, sin
 
 
 def set_Id_Iq(self, I0, Phi0):
-    """Set Id_ref and Iq_ref according to I0, Phi0
-    """
+    """Set Id_ref and Iq_ref according to I0, Phi0"""
 
     self.Id_ref = I0 * cos(Phi0)
     self.Iq_ref = I0 * sin(Phi0)
