@@ -5,6 +5,8 @@ from matplotlib.pyplot import axis, legend
 from numpy import exp
 
 from ....Functions.init_fig import init_fig
+from ....Functions.labels import HOLEM_LAB, decode_label
+from ....Functions.Geometry.transform_hole_surf import transform_hole_surf
 from ....definitions import config_dict
 from ....Methods import ParentMissingError
 
@@ -19,6 +21,7 @@ def plot(
     is_add_arrow=False,
     is_add_ref=False,
     is_show_fig=True,
+    is_all_hole=False,
 ):
     """Plot the Hole in a matplotlib fig
 
@@ -35,6 +38,8 @@ def plot(
         To add an arrow for the magnetization
     is_add_ref : bool
         True to add the reference points of the surfaces
+    is_all_hole : bool
+        True to plot the Zh holes
 
     Returns
     -------
@@ -47,9 +52,16 @@ def plot(
         color = "w"
 
     surf_hole = self.build_geometry()
+    if is_all_hole:
+        # Duplicate the hole surfaces
+        surf_hole = transform_hole_surf(
+            hole_surf_list=surf_hole, Zh=self.Zh, sym=1, alpha=0, delta=0
+        )
+
     patches = list()
     for surf in surf_hole:
-        if "Magnet" in surf.label and display_magnet:
+        label_dict = decode_label(surf.label)
+        if HOLEM_LAB in label_dict["surf_type"] and display_magnet:
             patches.extend(surf.get_patches(color=MAGNET_COLOR))
         else:
             patches.extend(surf.get_patches(color=color))
@@ -73,7 +85,11 @@ def plot(
             mag_surf = None
             mag_id = magnet_name.split("_")[-1]
             for surf in surf_hole:
-                if "Magnet" in surf.label and "_T" + mag_id in surf.label:
+                label_dict = decode_label(surf.label)
+                if (
+                    HOLEM_LAB in label_dict["surf_type"]
+                    and label_dict["T_id"] == mag_id
+                ):
                     mag_surf = surf
                     break
             # Create arrow coordinates
@@ -100,7 +116,7 @@ def plot(
     except ParentMissingError:
         pass
 
-    if display_magnet and "Magnet" in [surf.label for surf in surf_hole]:
+    if display_magnet and HOLEM_LAB in [surf.label for surf in surf_hole]:
         patch_leg.append(Patch(color=MAGNET_COLOR))
         label_leg.append("Magnet")
         legend(patch_leg, label_leg)
